hashstring

Macro hashstring 

hashstring!() { /* proc-macro */ }
Available on crate features hashstrings and macros only.
Hash a string so that it can be searched for in the resulting executable without including the actual string. This macro creates a case sensitive encrust::Hashstring.

Example

let look_for_me = hashstring!("Find me!");
assert!(look_for_me == "Find me!");
assert!(look_for_me != "fInD Me!");